Relational Multi-Head Attention
-------------------------------
The ``mi_module_zoo.relationalmultiheadattention`` contains implementations of
transformer-based models that process sets.

.. autoclass:: mi_module_zoo.relationalmultiheadattention.RelationalMultiheadAttention
   :members: forward
   :undoc-members:
